@@ -1,4 +1,4 @@
-/* $Id: mkzftree.c,v 1.17 2004/07/20 04:04:22 hpa Exp $ */
+/* $Id: mkzftree.c,v 1.18 2006/07/04 04:57:42 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2001 H. Peter Anvin - All Rights Reserved
@@ -59,6 +59,8 @@
  * The block data is compressed according to "zlib".
  */
 
+#include "mkzftree.h"		/* Must be included first! */
+
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
@@ -69,13 +71,12 @@
 #include <sys/types.h>
 #include <sys/time.h>
 
-#include "mkzftree.h"
-#include "version.h"
-
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
 
+#include "version.h"
+
 /* Command line options */
 struct cmdline_options opt = {
   0,				/* Force compression */
